pub struct DockerOpenCodeAdapter { /* private fields */ }Expand description
Docker OpenCode adapter for communicating with containerized agents.
Implementations
Sourceimpl DockerOpenCodeAdapter
impl DockerOpenCodeAdapter
Sourcepub fn new(
base_url: &str,
notification_tx: Sender<Value>,
) -> DockerOpenCodeAdapter
pub fn new( base_url: &str, notification_tx: Sender<Value>, ) -> DockerOpenCodeAdapter
Create a new adapter for communicating with a Docker container.
Sourcepub async fn connect(&self) -> Result<(), String>
pub async fn connect(&self) -> Result<(), String>
Connect to the container by performing a health check.
Sourcepub async fn create_session(
&self,
title: Option<&str>,
) -> Result<String, String>
pub async fn create_session( &self, title: Option<&str>, ) -> Result<String, String>
Create a new session in the container.
Sourcepub async fn set_local_session_id(&self, session_id: &str)
pub async fn set_local_session_id(&self, session_id: &str)
Set the local session ID (Routa’s session ID).
Sourcepub async fn get_remote_session_id(&self) -> Option<String>
pub async fn get_remote_session_id(&self) -> Option<String>
Get the remote session ID.