pub struct AcpPaths { /* private fields */ }Expand description
ACP paths manager for local agent installation.
Implementations
Sourceimpl AcpPaths
impl AcpPaths
Sourcepub fn with_base_dir(base_dir: PathBuf) -> AcpPaths
pub fn with_base_dir(base_dir: PathBuf) -> AcpPaths
Create AcpPaths with a custom base directory (for testing).
Sourcepub fn agent_version_dir(&self, agent_id: &str, version: &str) -> PathBuf
pub fn agent_version_dir(&self, agent_id: &str, version: &str) -> PathBuf
Get the directory for a specific agent version.
Sourcepub fn downloads_dir(&self) -> PathBuf
pub fn downloads_dir(&self) -> PathBuf
Get the downloads directory.
Sourcepub fn agent_download_dir(&self, agent_id: &str, version: &str) -> PathBuf
pub fn agent_download_dir(&self, agent_id: &str, version: &str) -> PathBuf
Get the download directory for a specific agent version.
Sourcepub fn runtimes_dir(&self) -> PathBuf
pub fn runtimes_dir(&self) -> PathBuf
Get the runtimes directory.
Sourcepub fn runtime_dir(&self, runtime: &str, version: &str) -> PathBuf
pub fn runtime_dir(&self, runtime: &str, version: &str) -> PathBuf
Get the directory for a specific runtime.
Sourcepub fn registry_cache_path(&self) -> PathBuf
pub fn registry_cache_path(&self) -> PathBuf
Get the path to the registry cache file.
Sourcepub fn installed_state_path(&self) -> PathBuf
pub fn installed_state_path(&self) -> PathBuf
Get the path to the installed agents state file.
Sourcepub fn ensure_directories(&self) -> Result<(), Error>
pub fn ensure_directories(&self) -> Result<(), Error>
Ensure all required directories exist.
Sourcepub fn current_platform() -> String
pub fn current_platform() -> String
Get the current platform target string. Returns format like “darwin-aarch64”, “darwin-x86_64”, “linux-x86_64”, etc.