AcpPaths

Struct AcpPaths 

pub struct AcpPaths { /* private fields */ }
ACP paths manager for local agent installation.

Implementations

Source

impl AcpPaths

pub fn new() -> AcpPaths

Create a new AcpPaths instance using the system data directory.

pub fn with_base_dir(base_dir: PathBuf) -> AcpPaths

Create AcpPaths with a custom base directory (for testing).

pub fn base_dir(&self) -> &PathBuf

Get the base directory for all ACP agent data.

pub fn agent_dir(&self, agent_id: &str) -> PathBuf

Get the directory for a specific agent.

pub fn agent_version_dir(&self, agent_id: &str, version: &str) -> PathBuf

Get the directory for a specific agent version.

pub fn downloads_dir(&self) -> PathBuf

Get the downloads directory.

pub fn agent_download_dir(&self, agent_id: &str, version: &str) -> PathBuf

Get the download directory for a specific agent version.

pub fn runtimes_dir(&self) -> PathBuf

Get the runtimes directory.

pub fn runtime_dir(&self, runtime: &str, version: &str) -> PathBuf

Get the directory for a specific runtime.

pub fn icons_dir(&self) -> PathBuf

Get the icons directory.

pub fn registry_cache_path(&self) -> PathBuf

Get the path to the registry cache file.

pub fn installed_state_path(&self) -> PathBuf

Get the path to the installed agents state file.

pub fn ensure_directories(&self) -> Result<(), Error>

Ensure all required directories exist.

pub fn current_platform() -> String

Get the current platform target string. Returns format like “darwin-aarch64”, “darwin-x86_64”, “linux-x86_64”, etc.