pub async fn start_server(config: ServerConfig) -> Result<SocketAddr, String>Expand description
Start the embedded Rust backend server.
Returns the actual address the server is listening on.
pub async fn start_server(config: ServerConfig) -> Result<SocketAddr, String>Start the embedded Rust backend server.
Returns the actual address the server is listening on.