create_commit

Function create_commit 

pub fn create_commit(
    repo_path: &str,
    message: &str,
    files: Option<&[String]>,
) -> Result<String, String>
Create a commit with the given message If files are provided, stages them first Returns the SHA of the created commit