pub struct Database { /* private fields */ }Expand description
Thread-safe handle to the SQLite database.
Implementations
Sourceimpl Database
impl Database
Sourcepub fn open(db_path: &str) -> Result<Database, ServerError>
pub fn open(db_path: &str) -> Result<Database, ServerError>
Open (or create) a SQLite database at the given path.
Sourcepub fn open_in_memory() -> Result<Database, ServerError>
pub fn open_in_memory() -> Result<Database, ServerError>
Open an in-memory database (for testing).
Sourcepub fn with_conn<F, T>(&self, f: F) -> Result<T, ServerError>
pub fn with_conn<F, T>(&self, f: F) -> Result<T, ServerError>
Execute a closure with access to the database connection. Automatically handles locking and error conversion.
Sourcepub async fn with_conn_async<F, T>(&self, f: F) -> Result<T, ServerError>
pub async fn with_conn_async<F, T>(&self, f: F) -> Result<T, ServerError>
Execute a closure with access to the database connection (async-friendly).