pub struct AcpRuntimeManager { /* private fields */ }Expand description
Manages Node.js / uv runtime discovery and auto-download.
Implementations
Sourceimpl AcpRuntimeManager
impl AcpRuntimeManager
Sourcepub fn new(paths: AcpPaths) -> AcpRuntimeManager
pub fn new(paths: AcpPaths) -> AcpRuntimeManager
Create a new runtime manager backed by the given AcpPaths.
Sourcepub async fn is_runtime_available(&self, rt: &RuntimeType) -> bool
pub async fn is_runtime_available(&self, rt: &RuntimeType) -> bool
Returns true if the runtime is reachable (managed or system).
Sourcepub async fn get_version(&self, rt: &RuntimeType) -> Option<String>
pub async fn get_version(&self, rt: &RuntimeType) -> Option<String>
Run {binary} --version and return the trimmed first line of output.
Returns None if the runtime is not available or the command fails.
Sourcepub async fn get_runtime_path(&self, rt: &RuntimeType) -> Option<PathBuf>
pub async fn get_runtime_path(&self, rt: &RuntimeType) -> Option<PathBuf>
Return the best path for a runtime: managed first, then system.
Sourcepub fn get_system_runtime(&self, rt: &RuntimeType) -> Option<RuntimeInfo>
pub fn get_system_runtime(&self, rt: &RuntimeType) -> Option<RuntimeInfo>
Locate the runtime on the system PATH.
Sourcepub async fn get_managed_runtime(&self, rt: &RuntimeType) -> Option<RuntimeInfo>
pub async fn get_managed_runtime(&self, rt: &RuntimeType) -> Option<RuntimeInfo>
Locate a previously downloaded (managed) runtime.
Sourcepub async fn ensure_runtime(
&self,
rt: &RuntimeType,
) -> Result<RuntimeInfo, String>
pub async fn ensure_runtime( &self, rt: &RuntimeType, ) -> Result<RuntimeInfo, String>
Ensure the runtime is available, downloading it if necessary.
Returns a RuntimeInfo with the resolved path.