Module error

Module error 

Core error type for the Routa platform.

ServerError is used throughout the core domain (stores, RPC, etc.). When the axum feature is enabled, it also implements IntoResponse so it can be used directly as an axum handler error type.

Enums

ServerError